@@ -7,6 +7,19 @@ macro_rules! css_attributes {
     }};
 }
 
+#[macro_export]
+macro_rules! attributes_ensure {
+    ($f:tt, $field:tt, $t:ty) => {
+        #[inline]
+        fn $f(&mut self) -> &mut $t {
+            if self.$field.is_none() {
+                self.$field = Some(Default::default())
+            }
+            unsafe { self.$field.as_mut().unwrap_unchecked() }
+        }
+    };
+}
+
 #[macro_export]
 macro_rules! syntax_error {
     ($msg:literal $(,)?) => {
