@@ -1,6 +1,8 @@
 mod display;
 mod parser;
+mod torch;
 
+pub use self::torch::TailwindTorch;
 use super::*;
 use crate::TailwindSizing;
 
@@ -44,26 +46,6 @@ pub enum TailwindScroll {}
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindSnap {}
 
-#[derive(Debug, Copy, Clone)]
-enum TorchKind {
-    Auto,
-    None,
-    PanX,
-    PanL,
-    PanR,
-    PanY,
-    PanU,
-    PanD,
-    PinchZoom,
-    Manipulate,
-}
-
-#[doc=include_str!("grid-row.md")]
-#[derive(Debug, Copy, Clone)]
-pub struct TailwindTorch {
-    kind: TorchKind,
-}
-
 #[derive(Debug, Copy, Clone)]
 enum SelectKind {
     None,
