@@ -1,39 +1,28 @@
-use super::*;
+use std::{
+    collections::BTreeSet,
+    fmt::{Debug, Display, Formatter},
+};
+
+use crate::{
+    css_attributes, syntax_error, AnchorPoint, CssAttribute, CssBehavior, LengthUnit, Result, TailwindArbitrary,
+    TailwindBuilder, TailwindInstance,
+};
+
+pub use self::{
+    aspect_ratio::TailwindAspect, columns::TailwindColumns, container::TailwindContainer,
+    object_position::TailwindObjectPosition, visible::TailwindVisibility, z_index::TailWindZIndex,
+};
+
+mod aspect_ratio;
+mod columns;
+mod container;
 mod display;
+mod object_position;
 mod parser;
 #[cfg(test)]
 mod test;
-
-#[derive(Copy, Clone, Debug)]
-enum AspectKind {
-    Auto,
-    Radio(usize, usize),
-    Global(CssBehavior),
-}
-
-#[doc = include_str!("aspect-ratio.md")]
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindAspect {
-    kind: AspectKind,
-}
-
-#[doc = include_str!("container.md")]
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindContainer {}
-
-#[derive(Copy, Clone, Debug)]
-enum ColumnKind {
-    Auto,
-    Columns(u8),
-    Length(LengthUnit),
-    // Global(CssBehavior),
-}
-
-#[doc = include_str!("columns.md")]
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindColumns {
-    kind: ColumnKind,
-}
+mod visible;
+mod z_index;
 
 #[derive(Copy, Clone, Debug)]
 enum BreakKind {
@@ -140,21 +129,6 @@ pub struct TailwindObjectFit {
     kind: ObjectFit,
 }
 
-/// https://tailwindcss.com/docs/object-fit
-#[derive(Clone, Debug)]
-pub enum TailwindObjectPosition {
-    LeftTop,
-    Top,
-    RightTop,
-    Left,
-    Center,
-    Right,
-    LeftBottom,
-    Bottom,
-    RightBottom,
-    Custom { x: String, y: String },
-}
-
 #[derive(Copy, Clone, Debug)]
 enum Overflow {
     Auto,
@@ -200,28 +174,3 @@ enum PositionKind {
 pub struct TailwindPosition {
     kind: PositionKind,
 }
-
-#[derive(Copy, Clone, Debug)]
-enum Visibility {
-    Visible,
-    Invisible,
-}
-
-/// https://tailwindcss.com/docs/visibility
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindVisibility {
-    kind: Visibility,
-}
-
-#[derive(Copy, Clone, Debug)]
-enum ZIndex {
-    Auto,
-    Unit(usize),
-}
-
-#[doc = include_str!("z-index.md")]
-#[derive(Copy, Clone, Debug)]
-pub struct TailWindZIndex {
-    kind: ZIndex,
-    neg: bool,
-}
