@@ -1,7 +1,7 @@
 use super::*;
 
 impl Display for TailwindSpacing {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
     }
 }
