@@ -1,8 +1,19 @@
+mod decoration;
 mod display;
+mod leading;
 mod parser;
+mod tracking;
 
-use super::*;
+pub use self::decoration::*;
 
+use crate::{
+    css_attributes, syntax_error, CssAttribute, CssBehavior, LengthUnit, Result, TailwindArbitrary, TailwindBuilder,
+    TailwindColor, TailwindInstance,
+};
+use std::{
+    collections::BTreeSet,
+    fmt::{Display, Formatter},
+};
 /// font that unknown at parsing time
 #[derive(Debug, Clone)]
 pub enum TailwindFontArbitrary {
@@ -124,53 +135,7 @@ pub struct TailwindTextAlignment {
 #[doc = include_str!("text-color.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindTextColor {
-    pub(crate) color: ColorResolver,
-}
-
-#[derive(Debug, Copy, Clone)]
-enum TextDecoration {
-    Underline,
-    Overline,
-    ThroughLine,
-    None,
-}
-
-#[doc = include_str!("text-decoration.md")]
-#[derive(Debug, Copy, Clone)]
-pub struct TailwindTextDecoration {
-    kind: TextDecoration,
-}
-
-#[doc = include_str!("text-decoration-color.md")]
-#[derive(Debug, Clone)]
-pub struct TailwindDecorationColor {
-    pub(crate) color: ColorResolver,
-}
-
-#[derive(Debug, Copy, Clone)]
-enum DecorationStyle {
-    Solid,
-    Double,
-    Dotted,
-    Dashed,
-    Wavy,
-}
-
-#[doc = include_str!("text-decoration-style.md")]
-#[derive(Debug, Copy, Clone)]
-pub struct TailwindDecorationStyle {
-    kind: DecorationStyle,
-}
-
-#[doc = include_str!("text-decoration-thickness.md")]
-#[derive(Debug, Clone)]
-pub enum TailwindDecorationThickness {
-    /// <p style="text-decoration-line:underline;text-decoration-thickness:auto;">The quick brown fox jumps over the lazy dog.</p>
-    Auto,
-    /// <p style="text-decoration-line:underline;text-decoration-thickness:from-font;">The quick brown fox jumps over the lazy dog.</p>
-    FromFont,
-    /// <p style="text-decoration-line:underline;text-decoration-thickness:2px;">The quick brown fox jumps over the lazy dog.</p>
-    Unit(usize),
+    color: TailwindColor,
 }
 
 #[doc = include_str!("text-underline-offset.md")]
