@@ -44,11 +44,11 @@ impl TailwindInstruction {
             ["relative"] => TailwindPosition::Relative.boxed(),
             ["sticky"] => TailwindPosition::Sticky.boxed(),
             // https://tailwindcss.com/docs/top-right-bottom-left
-            ["inset", rest @ ..] => todo!(),
-            ["top", rest @ ..] => todo!(),
-            ["right", rest @ ..] => todo!(),
-            ["buttom", rest @ ..] => todo!(),
-            ["left", rest @ ..] => todo!(),
+            ["inset", _rest @ ..] => todo!(),
+            ["top", _rest @ ..] => todo!(),
+            ["right", _rest @ ..] => todo!(),
+            ["buttom", _rest @ ..] => todo!(),
+            ["left", _rest @ ..] => todo!(),
             // https://tailwindcss.com/docs/visibility
             ["visible"] => TailwindVisibility::Visible.boxed(),
             ["invisible"] => TailwindVisibility::Invisible.boxed(),
@@ -72,14 +72,13 @@ impl TailwindInstruction {
             ["content", rest @ ..] => Self::content_adaptor(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
             ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
+            ["place", rest @ ..] => Self::place_adaptor(rest, arbitrary)?,
             // justify catched
             // Spacing System
-            [p @ ("p" | "pl" | "pr" | "pm" | "pt" | "px" | "py"), rest @ ..] => {
-                TailwindSpacing::parse_padding(rest, p, arbitrary)?.boxed()
-            }
-            [m @ ("m" | "ml" | "mr" | "mm" | "mt" | "mx" | "my"), rest @ ..] => {
-                TailwindSpacing::parse_margin(rest, m, arbitrary)?.boxed()
-            }
+            [p @ ("p" | "pl" | "pr" | "pm" | "pt" | "px" | "py"), rest @ ..] =>
+                TailwindSpacing::parse_padding(rest, p, arbitrary)?.boxed(),
+            [m @ ("m" | "ml" | "mr" | "mm" | "mt" | "mx" | "my"), rest @ ..] =>
+                TailwindSpacing::parse_margin(rest, m, arbitrary)?.boxed(),
             ["space", "x", rest @ ..] => TailwindSpacing::parse_space(rest, 'x', arbitrary)?.boxed(),
             ["space", "y", rest @ ..] => TailwindSpacing::parse_space(rest, 'y', arbitrary)?.boxed(),
             // Sizing System
@@ -112,12 +111,12 @@ impl TailwindInstruction {
             ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
             ["list", rest @ ..] => Self::list_adaptor(rest, arbitrary)?,
             // https://tailwindcss.com/docs/text-decoration
-            ["underline"] => TailwindTextDecoration::Underline.boxed(),
-            ["overline"] => TailwindTextDecoration::Overline.boxed(),
-            ["line", "through"] => TailwindTextDecoration::ThroughLine.boxed(),
-            ["no", "underline"] => TailwindTextDecoration::None.boxed(),
+            ["underline"] => TailwindDecorationLine::Underline.boxed(),
+            ["overline"] => TailwindDecorationLine::Overline.boxed(),
+            ["line", "through"] => TailwindDecorationLine::ThroughLine.boxed(),
+            ["no", "underline"] => TailwindDecorationLine::None.boxed(),
             // https://tailwindcss.com/docs/text-decoration-color
-            ["decoration", rest @ ..] => Self::decoration_adaptor(rest, arbitrary)?,
+            ["decoration", rest @ ..] => TailwindDecoration::parse(rest, arbitrary)?,
             ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/text-transform
             ["uppercase"] => TailwindTextTransform::Uppercase.boxed(),
@@ -136,11 +135,11 @@ impl TailwindInstruction {
             // Backgrounds System
             // FIXME: https://tailwindcss.com/docs/background-blend-mode
             ["bg", rest @ ..] => Self::bg_adaptor(rest, arbitrary)?,
-            ["from", rest @ ..] => todo!(),
-            ["via", rest @ ..] => todo!(),
-            ["to", rest @ ..] => todo!(),
+            ["from", _rest @ ..] => todo!(),
+            ["via", _rest @ ..] => todo!(),
+            ["to", _rest @ ..] => todo!(),
             // Borders System
-            ["rounded", rest @ ..] => todo!(),
+            ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
             ["border", rest @ ..] => Self::border_adaptor(rest, arbitrary)?,
             ["divide", rest @ ..] => Self::divide_adaptor(rest, arbitrary)?,
             ["outline", rest @ ..] => Self::outline_adaptor(rest, arbitrary)?,
@@ -148,7 +147,7 @@ impl TailwindInstruction {
             // Effects System
             ["shadow", rest @ ..] => Self::shadow_adaptor(rest, arbitrary)?,
             ["opacity", rest @ ..] => TailwindOpacity::parse(rest, arbitrary)?.boxed(),
-            ["mix", "blend", rest @ ..] => todo!(),
+            ["mix", "blend", rest @ ..] => TailwindBlend::parse(rest, arbitrary)?.boxed(),
             // Filters System
             ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, false)?.boxed(),
             ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary, false)?.boxed(),
@@ -163,21 +162,21 @@ impl TailwindInstruction {
             // Tables System
             ["table", rest @ ..] => Self::table_adaptor(rest, arbitrary)?,
             // Transitions System
-            ["transition", rest @ ..] => todo!(),
+            ["transition", _rest @ ..] => todo!(),
             ["duration", rest @ ..] => TailwindDuration::parse(rest, arbitrary)?.boxed(),
-            ["ease", rest @ ..] => todo!(),
+            ["ease", _rest @ ..] => todo!(),
             ["delay", rest @ ..] => TailwindDelay::parse(rest, arbitrary)?.boxed(),
-            ["animate", rest @ ..] => todo!(),
+            ["animate", _rest @ ..] => todo!(),
             // Transforms System
             ["scale", "x", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(true), neg)?.boxed(),
             ["scale", "y", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(false), neg)?.boxed(),
             ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, None, neg)?.boxed(),
             ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary, neg)?.boxed(),
-            ["translate", "x", rest @ ..] => todo!(),
-            ["translate", "y", rest @ ..] => todo!(),
+            ["translate", "x", _rest @ ..] => todo!(),
+            ["translate", "y", _rest @ ..] => todo!(),
             ["skew", "x", rest @ ..] => TailwindSkew::parse(rest, arbitrary, true, neg)?.boxed(),
             ["skew", "y", rest @ ..] => TailwindSkew::parse(rest, arbitrary, false, neg)?.boxed(),
-            ["origin", rest @ ..] => todo!(),
+            ["origin", rest @ ..] => TailwindOrigin::parse(rest, arbitrary)?.boxed(),
             // Interactivity System
             ["accent", rest @ ..] => TailwindAccentColor::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/appearance
@@ -192,8 +191,8 @@ impl TailwindInstruction {
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
             // SVG System
-            ["fill", rest @ ..] => todo!(),
-            ["stroke", rest @ ..] => todo!(),
+            ["fill", _rest @ ..] => todo!(),
+            ["stroke", _rest @ ..] => todo!(),
             // Accessibility System
             ["sr", "only"] => TailwindScreenReader::new(true).boxed(),
             ["not", "sr", "only"] => TailwindScreenReader::new(false).boxed(),
@@ -203,7 +202,7 @@ impl TailwindInstruction {
         Ok(instance)
     }
     #[inline]
-    fn break_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn break_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/border-style
             ["normal"] => TailwindBreak::Normal.boxed(),
@@ -232,26 +231,39 @@ impl TailwindInstruction {
             ["clip", "content"] => TailwindBackgroundClip::Content.boxed(),
             ["clip", "text"] => TailwindBackgroundClip::Text.boxed(),
             // https://tailwindcss.com/docs/background-origin
-            ["clip", "padding"] => TailwindBackgroundOrigin::Padding.boxed(),
-            ["clip", "content"] => TailwindBackgroundClip::Content.boxed(),
-            ["clip", "text"] => TailwindBackgroundClip::Text.boxed(),
-            _ => return syntax_error!("Unknown border instructions: {}", str.join("-")),
+            ["origin", "padding"] => TailwindBackgroundOrigin::Padding.boxed(),
+            ["origin", "content"] => TailwindBackgroundOrigin::Content.boxed(),
+            ["origin", "border"] => TailwindBackgroundOrigin::Border.boxed(),
+            // https://tailwindcss.com/docs/background-repeat
+            ["repeat"] => TailwindBackgroundRepeat::Repeat.boxed(),
+            ["no", "repeat"] | ["repeat", "none"] => TailwindBackgroundRepeat::None.boxed(),
+            ["repeat", "x"] => TailwindBackgroundRepeat::RepeatX.boxed(),
+            ["repeat", "y"] => TailwindBackgroundRepeat::RepeatY.boxed(),
+            ["repeat", "round"] => TailwindBackgroundRepeat::Round.boxed(),
+            ["repeat", "space"] => TailwindBackgroundRepeat::Space.boxed(),
+            // https://tailwindcss.com/docs/background-size
+            ["auto"] => TailwindBackgroundSize::Auto.boxed(),
+            ["cover"] => TailwindBackgroundSize::Cover.boxed(),
+            ["contain"] => TailwindBackgroundSize::Contain.boxed(),
+            // https://tailwindcss.com/docs/background-blend-mode
+            ["blend", rest @ ..] => TailwindBackgroundBlend::parse(rest, arbitrary)?.boxed(),
+            _ => return syntax_error!("Unknown bg instructions: {}", str.join("-")),
         };
         Ok(out)
     }
     #[inline]
-    fn border_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn border_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // border
             // [] => TailwindBorderWidth::parse(),
 
             // https://tailwindcss.com/docs/border-style
-            ["solid"] => TailwindBorderStyle::Solid.into_instance(),
-            ["dashed"] => TailwindBorderStyle::Dashed.into_instance(),
-            ["dotted"] => TailwindBorderStyle::Dotted.into_instance(),
-            ["double"] => TailwindBorderStyle::Double.into_instance(),
-            ["hidden"] => TailwindBorderStyle::Hidden.into_instance(),
-            ["none"] => TailwindBorderStyle::None.into_instance(),
+            ["solid"] => TailwindBorderStyle::Solid.boxed(),
+            ["dashed"] => TailwindBorderStyle::Dashed.boxed(),
+            ["dotted"] => TailwindBorderStyle::Dotted.boxed(),
+            ["double"] => TailwindBorderStyle::Double.boxed(),
+            ["hidden"] => TailwindBorderStyle::Hidden.boxed(),
+            ["none"] => TailwindBorderStyle::None.boxed(),
             // https://tailwindcss.com/docs/border-collapse
             ["collapse"] => TailwindBorderCollapse::Collapse.into_instance(),
             ["separate"] => TailwindBorderCollapse::Separate.into_instance(),
@@ -267,13 +279,13 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn divide_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn divide_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/divide-width
             ["x"] => todo!(),
-            ["x", n] => todo!(),
+            ["x", _n] => todo!(),
             ["y"] => todo!(),
-            ["y", n] => todo!(),
+            ["y", _n] => todo!(),
             // https://tailwindcss.com/docs/divide-style
             ["solid"] => TailwindDivideStyle::Solid.boxed(),
             ["dashed"] => TailwindDivideStyle::Dashed.boxed(),
@@ -286,7 +298,7 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn outline_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn outline_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/outline-style
             [] => todo!(),
@@ -296,9 +308,9 @@ impl TailwindInstruction {
             ["double"] => TailwindOutlineStyle::Double.boxed(),
             ["hidden"] => TailwindOutlineStyle::Hidden.boxed(),
             // https://tailwindcss.com/docs/outline-offset
-            ["offset", n] => todo!(),
+            ["offset", _n] => todo!(),
             // https://tailwindcss.com/docs/outline-width
-            [n] => todo!(),
+            [_n] => todo!(),
             _ => return syntax_error!("Unknown outline instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -324,7 +336,7 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn box_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn box_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             ["decoration", "clone"] => TailwindBoxDecoration::Clone.boxed(),
             ["decoration", "slice"] => TailwindBoxDecoration::Slice.boxed(),
@@ -364,11 +376,11 @@ impl TailwindInstruction {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after place");
         let out = match str {
             // https://tailwindcss.com/docs/grid-template-rows
-            ["rows", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["rows", _rest @ ..] => TailwindListStyle::None.boxed(),
             // https://tailwindcss.com/docs/grid-auto-flow
-            ["flow", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["flow", _rest @ ..] => TailwindListStyle::None.boxed(),
             // https://tailwindcss.com/docs/place-self
-            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["self", _rest @ ..] => TailwindListStyle::None.boxed(),
             _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -377,13 +389,12 @@ impl TailwindInstruction {
     fn justify_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
         let out = match str {
-            // https://tailwindcss.com/docs/justify-content
-            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
             // https://tailwindcss.com/docs/justify-items
-            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["items", rest @ ..] => TailwindJustifyItems::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/justify-self
-            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
-            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
+            ["self", rest @ ..] => TailwindJustifySelf::parse(rest, arbitrary)?.boxed(),
+            // https://tailwindcss.com/docs/justify-content
+            _ => TailwindJustifyContent::parse(str, arbitrary)?.boxed(),
         };
         Ok(out)
     }
@@ -407,15 +418,14 @@ impl TailwindInstruction {
     }
     #[inline]
     fn place_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after place");
         let out = match str {
             // https://tailwindcss.com/docs/place-content
-            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["content", rest @ ..] => TailwindPlaceContent::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/place-items
-            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["items", rest @ ..] => TailwindPlaceItems::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/place-self
-            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
-            _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
+            ["self", rest @ ..] => TailwindPlaceSelf::parse(rest, arbitrary)?.boxed(),
+            _ => return syntax_error!("Unknown place instructions: {}", str.join("-")),
         };
         Ok(out)
     }
@@ -435,36 +445,23 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn decoration_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
-        let out = match str {
-            // https://tailwindcss.com/docs/justify-content
-            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/justify-items
-            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/justify-self
-            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
-            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
+
     #[inline]
     fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
         let out = match str {
             // https://tailwindcss.com/docs/justify-content
-            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["content", _rest @ ..] => TailwindListStyle::None.boxed(),
             // https://tailwindcss.com/docs/justify-items
-            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["items", _rest @ ..] => TailwindListStyle::None.boxed(),
             // https://tailwindcss.com/docs/justify-self
-            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            ["self", _rest @ ..] => TailwindListStyle::None.boxed(),
             _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
         };
         Ok(out)
     }
     #[inline]
-    fn table_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn table_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             ["caption"] => TailwindTableLayout::Auto.boxed(),
             ["right"] => TailwindTableLayout::Auto.boxed(),
@@ -480,8 +477,8 @@ impl TailwindInstruction {
     }
 
     #[inline]
-    fn object_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
+    fn object_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+        let out = match pattern {
             // https://tailwindcss.com/docs/object-fit
             ["contain"] => TailwindObjectFit::Contain.boxed(),
             ["cover"] => TailwindObjectFit::Cover.boxed(),
@@ -489,17 +486,7 @@ impl TailwindInstruction {
             ["none"] => TailwindObjectFit::None.boxed(),
             ["scale", "down"] => TailwindObjectFit::ScaleDown.boxed(),
             // https://tailwindcss.com/docs/object-position
-            ["7"] | ["left", "top"] => TailwindObjectPosition::LeftTop.boxed(),
-            ["8"] | ["top"] => TailwindObjectPosition::Bottom.boxed(),
-            ["9"] | ["right", "top"] => TailwindObjectPosition::Bottom.boxed(),
-            ["4"] | ["left"] => TailwindObjectPosition::Bottom.boxed(),
-            ["5"] | ["center"] => TailwindObjectPosition::Bottom.boxed(),
-            ["6"] | ["right"] => TailwindObjectPosition::Bottom.boxed(),
-            ["1"] | ["left", "buttom"] => TailwindObjectPosition::Bottom.boxed(),
-            ["2"] | ["buttom"] => TailwindObjectPosition::Bottom.boxed(),
-            ["3"] | ["right", "buttom"] => TailwindObjectPosition::Bottom.boxed(),
-            [] => TailwindObjectPosition::parse_arbitrary(arbitrary)?.boxed(),
-            _ => return syntax_error!("Unknown object instructions: {}", str.join("-")),
+            _ => TailwindObjectPosition::parse(pattern, arbitrary)?.boxed(),
         };
         Ok(out)
     }
@@ -525,7 +512,7 @@ impl TailwindInstruction {
     }
 
     #[inline]
-    fn font_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn font_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/float
             [s @ ("sans" | "serif" | "mono")] => TailwindFontFamily::new(s).boxed(),
@@ -558,7 +545,7 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn text_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn text_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/text-align
             ["left"] => TailwindTextAlignment::Left.boxed(),
@@ -566,12 +553,12 @@ impl TailwindInstruction {
             ["right"] => TailwindTextAlignment::Right.boxed(),
             ["justify"] => TailwindTextAlignment::Justify.boxed(),
             // https://tailwindcss.com/docs/text-color
-            ["inherit"] => TailwindTextColor::INHERIT.boxed(),
-            ["current"] => TailwindTextColor::CURRENT.boxed(),
-            ["transparent"] => TailwindTextColor::TRANSPARENT.boxed(),
-            ["black"] => TailwindTextColor::BLACK.boxed(),
-            ["white"] => TailwindTextColor::WHITE.boxed(),
-            [color, weight] => TailwindTextColor::parse(color, weight)?.boxed(),
+            // ["inherit"] => TailwindTextColor::INHERIT.boxed(),
+            // ["current"] => TailwindTextColor::CURRENT.boxed(),
+            // ["transparent"] => TailwindTextColor::TRANSPARENT.boxed(),
+            // ["black"] => TailwindTextColor::BLACK.boxed(),
+            // ["white"] => TailwindTextColor::WHITE.boxed(),
+            // [color, weight] => TailwindTextColor::parse(color, weight)?.boxed(),
             _ => return syntax_error!("Unknown text instructions: {}", str.join("-")),
         };
         Ok(out)
